# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "advia_chimie_xpt"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&||||||||||P|1
    P|1|036666666|L036666666||NYME^ANO||20110513|F|||||PRESCRIBER||||||||||||LOC
    O|1|123456||^^^A\\^^^B|S|20130603110342|||||A||||Serum||||||||||O
    O|2|123456||^^^C|S|20130603110342|||||C||||Serum||||||||||O
    L|1|F
    """
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&|||UIW_LIS|||||LIS_ID||P|1
    Q|1|^SID10768||ALL||||||||O
    L|1
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "SID10768"}],
    }
    assert worklist == expected


def test_decode_result(self):
    date = datetime.datetime(2014, 8, 27, 8, 7)
    worklist = self.decode(
        """
    H|\\^&|||UIW_LIS|||||LIS_ID||P|1
    P|1|PID1123|||Peters^Cassie||19721221|F|||||DR1265A
    O|1|124123||^^^T4\\^^^T3\\^^^TSH|R||||||||||||||||||||F
    R|1|^^^T4^^^1^DOSE|5.8|ug/dL||||F\\R||||201408270807
    R|2|^^^T4^^^1^COFF|1.0|ug/dL||||F\\R||||201408270807
    R|3|^^^T4^^^1^RLU|54688|||||F\\R||||201408270807
    R|4|^^^T3^^^1^DOSE^L002|1.27|ng/mL||||F\\R||||201408270807
    C|1|I|Hight limit|I
    C|1|I|Commentaire|G
    R|5|^^^AT3^^^1^DOSE^L002|2.27|ng/mL||||P||||201408270807
    L|1|R
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "T4DOSE", "date": date, "flags": [], "value": "5.8"},
                    {"code": "T4COFF", "date": date, "flags": [], "value": "1.0"},
                    {"code": "T4RLU", "date": date, "flags": [], "value": "54688"},
                    {
                        "code": "T3DOSE",
                        "date": date,
                        "flags": ["Hight limit"],
                        "value": "1.27",
                        "lots": [{"lot": "L002", "type": "reagent"}],
                    },
                ],
                "sample_id": "124123",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        """
    H|\\^&|||UIW_LIS|||||LIS_ID||P|1
    P|1
    O|1|K018101||^^^T3|R||||||Q||||||||||||||F
    M|1|SHD^CEN:NG^V1^O|LIG1|018101
    R|1|^^^T3^^^1^DOSE|1.27|ng/mL||||F\\R||||201409270807
    L|1|F
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "control_lot": "018101",
                "sample_id": "018101",
                "results": [
                    {
                        "code": "T3DOSE",
                        "value": "1.27",
                        "flags": [],
                        "date": datetime.datetime(2014, 9, 27, 8, 7),
                    }
                ],
            }
        ],
    }
    assert worklist == expected
