# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy
import datetime

from driverng import Worklist

parser_class = "hl7_sil"


def test_decode_order1(self):
    worklist = self.decode(
        """
    MSH|^~\\&|middleware||SIL||20101216095928||OML^O33^OML_O33|MSG0000057367|P|2.5|||AL|NE|
    PID|1|4645615191|0012541258||DUPONT^Sophie|DURAND|20011212|F|||10, rue test^chemin tutu^Toulouse^^31000^France|||0102030405
    NTE|1|P|Infos patient|
    PV1|1||SURG^Chambre^lit||||DUCH||||||||||||ADM_CLI|||||||||||||||20101210080101||||||||||||
    SPM|1|01||SERUM|
    OBR|1||0100000666|SANSORC^SANSORC||||||PREL^DU Préleveur||||||DUCH^DUCHEMIN|||||||||||^^^20101216095812^^R||||||||||
    ORC|NW||0100000667|0100000667|CM||||||||||20101216085010||
    OBR|1||0100000667|K^POTASSIUM|||||||||RensCli3|||DUCH^DUCHEMIN|||||||||||^^^20101216095812^^R||||||||||
    ORC|NW||0100000667|0100000667|CM||||||||||20101216085010||
    OBR|1||0100000667|CL^CHLORINE||||||||||||DUCH^DUCHEMIN|||||||||||^^^20101216095812^^R||||||||||
    ORC|NW||0100000667|0100000667|CM||||||||||20101216085010||
    OBR|1||0100000667|CRE^CREATIN||||||||||||DUCH^DUCHEMIN|||||||||||^^^20101216095812^^R||||||||||
    ORC|NW||0100000667|0100000667|CM||||||||||20101216085010||
    OBR|1||0100000667|UREA^UREA||||||||||||DUCH^DUCHEMIN|||||||||||^^^20101216095812^^R||||||||||
    NTE|1|P|Obs tube|
    OBX|1|NM|NA||12|mmol/L|||||F|||20110124134900||||||
    OBR|3|1210000015|121000001501|ALBSNG|||||||||||||||||||||||^^^20210226100800^^R
    OBX|3|ST|ALBSNG||55.00|g/L||||||||20210225154000|||||20210225174126
    OBX|3|ST|ACCUEIL||Résu Accueil|g/L|||||||||||||20210225174126
    OBX|3|ST|BADDATE||Résu Accueil|g/L||||||||20210231174126|||||20210231174126
    """
    )
    expected = {
        "samples": [
            {
                "type": "patient",
                "sample_id": "0100000666",
                "request_id": "0012541258",
                "patient_id": "4645615191",
                "last_name": "DUPONT",
                "first_name": "Sophie",
                "title": "",
                "maiden_name": "DURAND",
                "birthdate": datetime.datetime(2001, 12, 12, 0, 0),
                "sex": "F",
                "location": "SURG",
                "alternate_patient_id": "ADM_CLI",
                "admission_date": None,
                "room": "Chambre",
                "bed": "lit",
                "collection_date": datetime.datetime(2010, 12, 16, 9, 58, 12),
                "request_date": datetime.datetime(2010, 12, 16, 9, 58, 12),
                "city": "Toulouse",
                "postal_code": "31000",
                "country": "France",
                "address": "10, rue test~chemin tutu",
                "phone": "0102030405",
                "comments": [{"type": "patient", "text": "Infos patient"}],
                "orders": [{"code": "SANSORC", "priority": "R", "action": "add"}],
                "physicians": [
                    {"code": "DUCH", "last_name": "DUCHEMIN", "type": "prescriber"},
                    {"code": "PREL", "last_name": "DU Préleveur", "type": "sampler"},
                ],
            },
            {
                "type": "patient",
                "sample_id": "0100000667",
                "request_id": "0012541258",
                "patient_id": "4645615191",
                "last_name": "DUPONT",
                "first_name": "Sophie",
                "title": "",
                "maiden_name": "DURAND",
                "birthdate": datetime.datetime(2001, 12, 12, 0, 0),
                "sex": "F",
                "diagnostic": "RensCli3",
                "address": "10, rue test~chemin tutu",
                "postal_code": "31000",
                "city": "Toulouse",
                "country": "France",
                "phone": "0102030405",
                "location": "SURG",
                "room": "Chambre",
                "bed": "lit",
                "alternate_patient_id": "ADM_CLI",
                "admission_date": None,
                "collection_date": datetime.datetime(2010, 12, 16, 9, 58, 12),
                "request_date": datetime.datetime(2010, 12, 16, 8, 50, 10),
                "comments": [
                    {"type": "patient", "text": "Infos patient"},
                    {"type": "sample", "text": "Obs tube"},
                ],
                "orders": [
                    {"code": "K", "priority": "R", "action": "add"},
                    {"code": "CL", "priority": "R", "action": "add"},
                    {"code": "CRE", "priority": "R", "action": "add"},
                    {"code": "UREA", "priority": "R", "action": "add"},
                ],
                "physicians": [
                    {"code": "DUCH", "last_name": "DUCHEMIN", "type": "prescriber"}
                ],
                "results": [
                    {
                        "type": "NM",
                        "anterior": True,
                        "code": "NA",
                        "value": "12",
                        "date": datetime.datetime(2011, 1, 24, 13, 49),
                    }
                ],
            },
            {
                "type": "patient",
                "sample_id": "121000001501",
                "request_id": "1210000015",
                "patient_id": "4645615191",
                "last_name": "DUPONT",
                "first_name": "Sophie",
                "title": "",
                "maiden_name": "DURAND",
                "birthdate": datetime.datetime(2001, 12, 12, 0, 0),
                "sex": "F",
                "address": "10, rue test~chemin tutu",
                "postal_code": "31000",
                "city": "Toulouse",
                "country": "France",
                "phone": "0102030405",
                "location": "SURG",
                "room": "Chambre",
                "bed": "lit",
                "location": "SURG",
                "alternate_patient_id": "ADM_CLI",
                "admission_date": None,
                "request_date": datetime.datetime(2010, 12, 16, 8, 50, 10),
                "collection_date": datetime.datetime(2021, 2, 26, 10, 8),
                "comments": [{"type": "patient", "text": "Infos patient"}],
                "orders": [
                    {"code": "ALBSNG", "priority": "R", "action": "add"},
                    {"code": "ACCUEIL", "action": "add"},
                ],
                "results": [
                    {
                        "type": "ST",
                        "anterior": True,
                        "code": "ALBSNG",
                        "value": "55.00",
                        "date": datetime.datetime(2021, 2, 25, 15, 40),
                    },
                    {
                        "type": "ST",
                        "anterior": False,
                        "code": "ACCUEIL",
                        "value": "Résu Accueil",
                        "date": None,
                    },
                ],
            },
        ],
        "context": "order",
        "sender_id": "middleware",
        "receiver_id": "SIL",
    }
    assert worklist == expected


def test_decode_order_comment(self):
    worklist = self.decode(
        """
    MSH|^~\\&|SIL||ONELINK||20210305095220||ORM^O33^ORM_O33|3653145742875247561|P|2.5.1|||AL|NE||UNICODE UTF-8|||
    PID|1|100202020150|||TESTGLIMS^Sebastien||20101220|M
    NTE|1|P|Anoréxie
    PV1|1||||||||||||||||||123456789
    SPM|1|121000007701|||||||||P||||||20210305092913|20210305080808
    ORC|NW|1210000077|121000007701
    NTE|1|P|Sous Immunosuppresseur
    OBR|1|1210000077|121000007701|CORPSCET||||||||||||0340^^^^^^^^^^^^^^^^^^^^^SERV&Nom service|0102030405||||||||||^^^20210305092900^^R
    OBR|2|1210000077|121000007701|NITRITES|||||||||||||||||||||||^^^20210305092900^^R
    SPM|1|121000007701|||||||||P||||||20210305092913|20210305080808
    ORC|CA|1210000077|121000007701
    OBR|3|1210000077|121000007701|UROBILIN|||||||||||||||||||||||^^^20210305092900^^R
    NTE|1|P|Comment OBR
    ORC|NW|1210000077|121000007701
    OBR|3|1210000077|121000007701|URONEW|||||||||||||||||||||||^^^20210305092900^^R
    """
    )
    expected = {
        "samples": [
            {
                "type": "patient",
                "sample_id": "121000007701",
                "request_id": "1210000077",
                "request_date": datetime.datetime(2021, 3, 5, 8, 8, 8),
                "patient_id": "100202020150",
                "last_name": "TESTGLIMS",
                "first_name": "Sebastien",
                "title": "",
                "maiden_name": "",
                "birthdate": datetime.datetime(2010, 12, 20, 0, 0),
                "sex": "M",
                "location": None,
                "address": "",
                "postal_code": "",
                "city": "",
                "country": "",
                "phone": "",
                "room": "",
                "bed": "",
                "admission_date": None,
                "alternate_patient_id": "123456789",
                "collection_date": datetime.datetime(2021, 3, 5, 9, 29, 13),
                "comments": [
                    {"type": "sample", "text": "Sous Immunosuppresseur"},
                    {"type": "patient", "text": "Anoréxie"},
                    {"type": "sample", "text": "Comment OBR"},
                ],
                "orders": [
                    {"code": "CORPSCET", "priority": "R", "action": "add"},
                    {"code": "NITRITES", "priority": "R", "action": "add"},
                    {"code": "UROBILIN", "priority": "R", "action": "del"},
                    {"code": "URONEW", "priority": "R", "action": "add"},
                ],
                "physicians": [
                    {
                        "code": "0340",
                        "last_name": "",
                        "type": "prescriber",
                        "phone": "0102030405",
                    }
                ],
                "services": [
                    {"code": "SERV", "name": "Nom service", "phone": "0102030405"}
                ],
            }
        ],
        "context": "order",
        "sender_id": "SIL",
        "receiver_id": "ONELINK",
    }
    assert worklist == expected


def test_decode_result_other(self):
    worklist = self.decode(
        """
    MSH|^~\\&|SIL||cobasInfinity||20191112101611||OML^O33^OML_O33|SILORDER-65329-36970-000001|P|2.5|||AL|NE
    PID|1|0000077659|||TEST SIL^Connexion|SIL|20170207|M
    NTE|1|P||
    PV1|1||||||
    SPM|1|950000000003||ECBU
    ORC|NW|950000000003|950000000003
    OBR|1|9500000000|950000000003|ECBU^ECBU||||||||||||^RDF|||||||||||^^^20191112101607^^R
    NTE|1|P|Infos tube|"""
    )
    expected = {
        "context": "order",
        "sender_id": "SIL",
        "receiver_id": "cobasInfinity",
        "samples": [
            {
                "type": "patient",
                "sample_id": "950000000003",
                "request_id": "9500000000",
                "request_date": datetime.datetime(2019, 11, 12, 10, 16, 7),
                "patient_id": "0000077659",
                "last_name": "TEST SIL",
                "first_name": "Connexion",
                "title": "",
                "maiden_name": "SIL",
                "birthdate": datetime.datetime(2017, 2, 7, 0, 0),
                "sex": "M",
                "location": None,
                "address": "",
                "postal_code": "",
                "city": "",
                "country": "",
                "phone": "",
                "room": None,
                "bed": None,
                "admission_date": None,
                "alternate_patient_id": None,
                "admission_date": None,
                "collection_date": datetime.datetime(2019, 11, 12, 10, 16, 7),
                "comments": [{"type": "sample", "text": "Infos tube"}],
                "orders": [{"code": "ECBU", "priority": "R", "action": "add"}],
            }
        ],
    }
    assert worklist == expected


def test_decode_without_demande_id(self):
    try:
        worklist = self.decode(
            """
        MSH|^~\\&|SIL||cobasInfinity||20191112101611||OML^O33^OML_O33|SILORDER-65329-36970-000001|P|2.5|||AL|NE
        PID|1|0000077659|||TEST SIL^Connexion|SIL|20170207|M
        NTE|1|P||
        PV1|1||||||
        SPM|1|950000000003||ECBU
        ORC|NW|950000000003|950000000003
        OBR|1||950000000003|ECBU^ECBU||||||||||||^RDF|||||||||||^^^20191112101607^^R
        NTE|1|P|Infos tube|"""
        )
    except RuntimeError:
        worklist = None
    assert worklist is None


def test_encode_result(self):
    result_worklist = copy.deepcopy(self.result_worklist)
    result_worklist.samples[0].collection_date = datetime.datetime(
        2013, 5, 13, 10, 40, 3
    )
    result_worklist.samples[0].results[0].comments = ["Comment 1", "Comment 2"]
    result_worklist.samples[0].results.add(
        {
            "type": "GC",
            "code": "ELECGR",
            "value": [
                {"value": 3, "label": None, "codification": None},
                {"value": 2, "label": None, "codification": None},
                {"value": 1, "label": None, "codification": None},
            ],
            "date": datetime.datetime(2021, 2, 25, 15, 40),
        }
    )
    result_worklist.samples[0].results.add(
        {
            "status": "F",
            "code": "T1",
            "lots": [],
            "value": [{"codification": "L", "value": "TCODE", "label": "Texte Code"}],
            "instrument": "Instrument",
            "validator": "Nom Prenom",
            "validator_code": "login",
            "operator": "OPE",
            "comments": [],
            "type": "CE",
            "unit": None,
            "date": datetime.datetime(2021, 2, 25, 15, 40),
        }
    )

    message = self.result(
        worklist=result_worklist, context={"control_id": "1521651964637"}
    )
    expected = """
    MSH|^~\\&|MCA||||20130715141912||OUL^R22^OUL_R22|1521651964637||2.5.1|||AL|NE||UNICODE UTF-8
    PID|1|036666666|036666666||NYME^ANO^^^Mme|NJF|20110513|F
    PV1|1||LOC||||ATTENDING^Joseph-Louis|PRESCRIBER|||||||||||ADM_CLI|||||||||||||||||||||||||20130511103030|20130514103001
    SPM|1|123456|||||||||P||||||20130513104003|20130603110342
    OBR|1|78910|123456|A|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513104003
    OBX|1|NM|A||42|mV|||||P|||20110506121400||VAL||INST
    NTE|1|L|Comment 1
    NTE|2|L|Comment 2
    OBR|2|78910|123456|B|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513104003
    OBX|1|CE|B||NORESULT|mV||HH~>|||P|||20110506121400||VAL||INST
    OBR|3|78910|123456|C|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513104003
    OBX|1|NM|C||42|mV|||||P|||20110506121400||VAL||INST
    NTE|1|L|Abnormal
    NTE|2|L|EE
    OBR|4|78910|123456|ELECGR|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513104003
    OBX|1|GC|ELECGR||3~2~1||||||P|||20210225154000
    OBR|5|78910|123456|T1|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513104003|||||||OPE
    OBX|1|CE|T1||TCODE^Texte Code^L||||||P|||20210225154000||Nom Prenom||Instrument
    """
    assert message == expected
    self.configure(option_alarme_analytique=True)
    message = self.result(
        worklist=result_worklist, context={"control_id": "1521651964637"}
    )
    expected = """
    MSH|^~\\&|MCA||||20130715141912||OUL^R22^OUL_R22|1521651964637||2.5.1|||AL|NE||UNICODE UTF-8
    PID|1|036666666|036666666||NYME^ANO^^^Mme|NJF|20110513|F
    PV1|1||LOC||||ATTENDING^Joseph-Louis|PRESCRIBER|||||||||||ADM_CLI|||||||||||||||||||||||||20130511103030|20130514103001
    SPM|1|123456|||||||||P||||||20130513104003|20130603110342
    OBR|1|78910|123456|A|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513104003
    OBX|1|NM|A||42|mV|||||P|||20110506121400||VAL||INST
    NTE|1|L|Comment 1
    NTE|2|L|Comment 2
    OBR|2|78910|123456|B|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513104003
    OBX|1|CE|B||NORESULT|mV||LL~<|||P|||20110506121400||VAL||INST
    OBR|3|78910|123456|C|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513104003
    OBX|1|NM|C||42|mV|||||P|||20110506121400||VAL||INST
    NTE|1|L|Abnormal
    NTE|2|L|EE
    OBR|4|78910|123456|ELECGR|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513104003
    OBX|1|GC|ELECGR||3~2~1||||||P|||20210225154000
    OBR|5|78910|123456|T1|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513104003|||||||OPE
    OBX|1|CE|T1||TCODE^Texte Code^L||||||P|||20210225154000||Nom Prenom||Instrument
    """


def test_encode_control(self):
    result_control_worklist = copy.deepcopy(self.result_control_worklist)
    result_control_worklist.samples[0].specimen = "U"
    message = self.result_control(
        worklist=result_control_worklist, context={"control_id": "1521651964637"}
    )
    expected = """
    MSH|^~\\&|MCA||||20130715141912||OUL^R22^OUL_R22|1521651964637||2.5.1|||AL|NE||UNICODE UTF-8
    SPM|1|CQ123456|||||||||QC
    SAC|1||CQ123456
    OBR|1||CQ123456|A
    OBX|1|NM|A||42|mV||HH~>|||P|||20110506121400||||INST
    OBR|2||CQ123456|B
    OBX|1|NM|B||4.40||||||P|||20110506121300||||INST
    INV|Reagent Name||reagent|REAGENT||||||||20120606120000
    INV|2||control|CONTROL
    INV|3||calibration|CALIBRATION
    SPM|2|CQ123488|||||||||QC
    SAC|1||CQ123488
    OBR|1||CQ123488|A
    OBX|1|NM|A||4|mV|||||P|||20110506121400||||INST
    """
    assert message == expected


def test_encode_atb_result(self):
    values = [
        {
            "code": "GERMEECBU",
            "date": datetime.datetime(2016, 11, 23, 16, 21, 26, 866192),
            "instrument": "INST",
            "lots": [],
            "operator": None,
            "status": "P",
            "sub_code": "1",
            "type": "CE",
            "unit": "",
            "validator": "VAL",
            "nom_antibiogramme": "NOM_ATB",
            "value": [
                {
                    "antibiogram": [
                        {
                            "antibiotic": "AM",
                            "mic": "<=2",
                            "sensitivity": "S",
                            "diameter": "12",
                            "cutoff": "6-13",
                            "cutoff_diameter": "2-4",
                            "antibiotic_texte_code": ("AM", "Ampicilline", "L"),
                        },
                        {
                            "antibiotic": "AMC",
                            "mic": "8",
                            "diameter": "15",
                            "sensitivity": "R",
                            "antibiotic_texte_code": ("AMC", "Amoxicilline", "L"),
                        },
                    ],
                    "codification": "L",
                    "label": "Escherichia coli",
                    "value": "ESCCOL",
                }
            ],
        },
        {
            "code": "GERMEECBU",
            "date": datetime.datetime(2016, 11, 23, 16, 21, 26, 866192),
            "instrument": "INST",
            "lots": [],
            "operator": None,
            "status": "P",
            "sub_code": "2",
            "type": "CE",
            "unit": "",
            "validator": "VAL",
            "value": [
                {
                    "antibiogram": [
                        {
                            "antibiotic": "AM",
                            "mic": "4",
                            "sensitivity": "R",
                            "diameter": "16",
                            "cutoff": "7-15",
                            "cutoff_diameter": "3-7",
                            "antibiotic_texte_code": ("AM", "Ampicilline", "L"),
                        },
                        {
                            "antibiotic": "AMC",
                            "mic": "<=0.25",
                            "sensitivity": "S",
                            "diameter": "13",
                            "antibiotic_texte_code": ("AMC", "Amoxicilline", "L"),
                        },
                    ],
                    "codification": "L",
                    "label": "Escherichia coli",
                    "value": "ESCCOL",
                }
            ],
        },
        {
            "code": "GERMEECBU",
            "date": datetime.datetime(2016, 11, 23, 16, 21, 26, 866192),
            "instrument": "INST",
            "lots": [],
            "operator": None,
            "status": "P",
            "sub_code": "3",
            "type": "CE",
            "unit": "",
            "validator": "VAL",
            "value": [
                {
                    "antibiogram": [
                        {
                            "antibiotic": "AM",
                            "mic": "1",
                            "sensitivity": "I",
                            "antibiotic_texte_code": ("AM", "Ampicilline", "L"),
                        },
                        {
                            "antibiotic": "AMC",
                            "mic": "2",
                            "sensitivity": "S",
                            "antibiotic_texte_code": ("AMC", "Amoxicilline", "L"),
                        },
                    ],
                    "codification": "L",
                    "label": "Citrobacter koseri",
                    "value": "CITDIV",
                }
            ],
        },
    ]
    result_worklist = Worklist(**self.result_worklist)
    result_worklist.samples[0].results = values
    message = self.encode(result_worklist, context={"control_id": "1521651964637"})
    expected = """
    MSH|^~\\&|MCA||||20130715141912||OUL^R22^OUL_R22|1521651964637||2.5.1|||AL|NE||UNICODE UTF-8
    PID|1|036666666|036666666||NYME^ANO^^^Mme|NJF|20110513|F
    PV1|1||LOC||||ATTENDING^Joseph-Louis|PRESCRIBER|||||||||||ADM_CLI|||||||||||||||||||||||||20130511103030|20130514103001
    SPM|1|123456|||||||||P||||||20130513114242|20130603110342
    OBR|1|78910|123456|GERMEECBU|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513114242^^R
    OBX|1|CE|GERMEECBU^^GERMEATB^1||ESCCOL&Escherichia coli&L||||||P|||20161123162126||VAL||INST
    OBX|2|CE|ESCCOL^^ANTIBIOTIC^1||AM&Ampicilline&L^S^<=2^12^6-13^2-4||||||P|||20161123162126|^^GERMEECBU^^^1|VAL||INST
    OBX|3|CE|ESCCOL^^ANTIBIOTIC^2||AMC&Amoxicilline&L^R^8^15||||||P|||20161123162126|^^GERMEECBU^^^1|VAL||INST
    OBX|4|CE|GERMEECBU^^GERMEATB^2||ESCCOL&Escherichia coli&L||||||P|||20161123162126||VAL||INST
    OBX|5|CE|ESCCOL^^ANTIBIOTIC^1||AM&Ampicilline&L^R^4^16^7-15^3-7||||||P|||20161123162126|^^GERMEECBU^^^2|VAL||INST
    OBX|6|CE|ESCCOL^^ANTIBIOTIC^2||AMC&Amoxicilline&L^S^<=0.25^13||||||P|||20161123162126|^^GERMEECBU^^^2|VAL||INST
    OBX|7|CE|GERMEECBU^^GERMEATB^3||CITDIV&Citrobacter koseri&L||||||P|||20161123162126||VAL||INST
    OBX|8|CE|CITDIV^^ANTIBIOTIC^1||AM&Ampicilline&L^I^1||||||P|||20161123162126|^^GERMEECBU^^^3|VAL||INST
    OBX|9|CE|CITDIV^^ANTIBIOTIC^2||AMC&Amoxicilline&L^S^2||||||P|||20161123162126|^^GERMEECBU^^^3|VAL||INST
    """
    assert message == expected


def test_encode_ident_result(self):
    result_worklist = Worklist(**self.result_worklist)
    result_worklist.samples[0].results = [
        {
            "code": "IDENTPV",
            "type": "CE",
            "date": datetime.datetime(2016, 11, 23, 16, 21, 26, 866192),
            "instrument": "INST",
            "status": "P",
            "sub_code": None,
            "value": [
                {
                    "multiple_clarilab": [["ESCCOL", "1", "CITDIV", "1000"]],
                    "json": {
                        "germes": [
                            {"id": "ESCCOL", "qty": "1", "rang": 1},
                            {"id": "CITDIV", "qty": "1000", "rang": 2},
                        ],
                        "resultat": "BAC_POS",
                        "type_resultat": "identification_germes",
                    },
                    "schema": {
                        "type": "object",
                        "properties": {
                            "germes": {
                                "items": {
                                    "type": "object",
                                    "properties": {
                                        "id": {
                                            "type": "string",
                                            "propertyOrder": 0,
                                            "format": {
                                                "mode_saisie": "popup",
                                                "code": "id",
                                                "libelle": "Identification",
                                                "classtcode": ["GERMES"],
                                                "textescodes": {
                                                    "ESCCOL": (
                                                        "ESCCOL",
                                                        "Escherichia coli",
                                                        "L",
                                                    ),
                                                    "CITDIV": (
                                                        "CITDIV",
                                                        "Citrobacter koseri",
                                                        "L",
                                                    ),
                                                },
                                            },
                                        },
                                        "qty": {
                                            "type": "string",
                                            "propertyOrder": 1,
                                            "format": {
                                                "mode_saisie": "combo",
                                                "code": "qty",
                                                "libelle": "Quantité",
                                                "classtcode": ["QUANTITES"],
                                                "textescodes": {
                                                    "1": ("1", "Un", "L"),
                                                    "1000": ("1000", "Beaucoup", "L"),
                                                },
                                            },
                                        },
                                    },
                                },
                                "title": "Germes",
                                "propertyOrder": 0,
                                "type": "array",
                            }
                        },
                    },
                    "codification": "L",
                    "value": "BAC_POS",
                    "label": "Positive",
                }
            ],
        }
    ]
    message = self.encode(result_worklist, context={"control_id": "1521651964637"})
    expected = """
    MSH|^~\\&|MCA||||20130715141912||OUL^R22^OUL_R22|1521651964637||2.5.1|||AL|NE||UNICODE UTF-8
    PID|1|036666666|036666666||NYME^ANO^^^Mme|NJF|20110513|F
    PV1|1||LOC||||ATTENDING^Joseph-Louis|PRESCRIBER|||||||||||ADM_CLI|||||||||||||||||||||||||20130511103030|20130514103001
    SPM|1|123456|||||||||P||||||20130513114242|20130603110342
    OBR|1|78910|123456|IDENTPV|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513114242^^R
    OBX|1|CE|IDENTPV||BAC_POS^Positive^L||||||P|||20161123162126||||INST
    OBX|2|CE|IDENTPV^^COMPLEXE^1||1^ESCCOL&Escherichia coli&id^1&Un&qty||||||P|||20161123162126|^^IDENTPV|||INST
    OBX|3|CE|IDENTPV^^COMPLEXE^2||2^CITDIV&Citrobacter koseri&id^1000&Beaucoup&qty||||||P|||20161123162126|^^IDENTPV|||INST
    """
    assert message == expected


def test_encode_ident_result_2(self):
    result_worklist = Worklist(**self.result_worklist)
    result_worklist.samples[0].results = [
        {
            "code": "CBU3_3URCU",
            "type": "CE",
            "sub_code": None,
            "value": [
                {
                    "value": "PCBU",
                    "label": "PCBU Positive",
                    "codification": "L",
                    "multiple_clarilab": [["#", "#", "KLEPN", "#", "#", "#"]],
                    "json": {
                        "type_resultat": "identification_germes",
                        "germes": [{"id": "KLEPN", "rang": 1, "score": "A_2.47"}],
                        "seq": "0",
                        "resultat": "PCBU",
                    },
                    "schema": {
                        "type": "object",
                        "properties": {
                            "germes": {
                                "propertyOrder": 0,
                                "items": {
                                    "type": "object",
                                    "properties": {
                                        "atb": {
                                            "propertyOrder": 4,
                                            "type": "string",
                                            "format": {
                                                "mode_saisie": "popup",
                                                "largeur": "6",
                                                "code": "atb",
                                                "libelle": "ATB?",
                                                "classtcode": ["ATBG"],
                                                "textescodes": {"#": ("#", "", "L")},
                                            },
                                        },
                                        "bmr": {
                                            "propertyOrder": 5,
                                            "type": "string",
                                            "format": {
                                                "mode_saisie": "popup",
                                                "largeur": "6",
                                                "code": "bmr",
                                                "libelle": "BMR?",
                                                "classtcode": ["BMRG"],
                                                "textescodes": {"#": ("#", "", "L")},
                                            },
                                        },
                                        "idlev": {
                                            "propertyOrder": 3,
                                            "type": "string",
                                            "format": {
                                                "classtcode": ["MYCO", "CANDIDA"],
                                                "largeur": "6",
                                                "code": "idlev",
                                                "libelle": "Id Lev",
                                                "mode_saisie": "popup",
                                                "textescodes": {"#": ("#", "", "L")},
                                            },
                                        },
                                        "num": {
                                            "propertyOrder": 0,
                                            "type": "string",
                                            "format": {
                                                "mode_saisie": "radio",
                                                "largeur": "6",
                                                "code": "num",
                                                "libelle": "Numération",
                                                "classtcode": ["NUMECBU"],
                                                "textescodes": {"#": ("#", "", "L")},
                                            },
                                        },
                                        "coli": {
                                            "propertyOrder": 1,
                                            "type": "string",
                                            "format": {
                                                "classtcode": ["COLI"],
                                                "largeur": "6",
                                                "code": "coli",
                                                "libelle": "coli",
                                                "mode_saisie": "radio",
                                                "textescodes": {"#": ("#", "", "L")},
                                            },
                                        },
                                        "id": {
                                            "propertyOrder": 2,
                                            "type": "string",
                                            "format": {
                                                "classtcode": [
                                                    "GERMFQ",
                                                    "GERMUR",
                                                    "GERME",
                                                ],
                                                "largeur": "6",
                                                "code": "id",
                                                "libelle": "id",
                                                "mode_saisie": "popup",
                                                "textescodes": {
                                                    "KLEPN": (
                                                        "KLEPN",
                                                        "Klebsiella pneumoniae",
                                                        "L",
                                                    )
                                                },
                                            },
                                        },
                                    },
                                },
                                "type": "array",
                                "title": "Germes (2 max)",
                            }
                        },
                    },
                }
            ],
            "flags": [],
            "date": datetime.datetime(2024, 2, 12, 14, 16),
            "operator": None,
            "status": "P",
            "validator": "auto",
            "unit": "",
            "nom_antibiogramme": None,
            "instrument": "bacms_resultats",
            "lots": [],
        }
    ]
    message = self.encode(result_worklist, context={"control_id": "1521651964637"})
    expected = """
    MSH|^~\\&|MCA||||20130715141912||OUL^R22^OUL_R22|1521651964637||2.5.1|||AL|NE||UNICODE UTF-8
    PID|1|036666666|036666666||NYME^ANO^^^Mme|NJF|20110513|F
    PV1|1||LOC||||ATTENDING^Joseph-Louis|PRESCRIBER|||||||||||ADM_CLI|||||||||||||||||||||||||20130511103030|20130514103001
    SPM|1|123456|||||||||P||||||20130513114242|20130603110342
    OBR|1|78910|123456|CBU3_3URCU|||||||||Information clinique|||PRESCRIBER^Prescriber|||||||||||^^^20130513114242^^R
    OBX|1|CE|CBU3_3URCU||PCBU^PCBU Positive^L||||||P|||20240212141600||auto||bacms_resultats
    OBX|2|CE|CBU3_3URCU^^COMPLEXE^1||1^KLEPN&Klebsiella pneumoniae&id||||||P|||20240212141600|^^CBU3_3URCU|auto||bacms_resultats
    """
    assert message == expected


def test_encode_extended_germes(self):
    wkjson = {
        "samples": [
            {
                "type": "patient",
                "sample_id": "124112003102",
                "patient_id": "581312",
                "alternate_patient_id": "7099166107",
                "lab_patient_id": "003542973",
                "maiden_name": "CIRCUIT",
                "sex": "M",
                "weight": None,
                "height": None,
                "birthdate": datetime.datetime(1982, 1, 1, 0, 0),
                "admission_date": None,
                "admission_end_date": None,
                "last_name": "CIRCUIT",
                "first_name": "TRACABILITE",
                "title": "Mr",
                "address": "chu montprellier test adresse",
                "city": "MONTPELLIER",
                "postal_code": "34090",
                "country": "",
                "room": "123",
                "bed": "",
                "phone": "0603030303",
                "physicians": [
                    {
                        "type": "prescriber",
                        "code": "01981949",
                        "last_name": "Riccio Nicolas",
                        "phone": "37329 - 37050-Salle de soins",
                    }
                ],
                "location": "0181",
                "request_id": "1241120031",
                "request_date": datetime.datetime(2024, 3, 12, 13, 46, 40),
                "collection_date": datetime.datetime(2024, 3, 12, 13, 46),
                "collection_end_date": None,
                "priority": "R",
                "nature": {"code": "BACTERIO", "label": None},
                "services": [{"code": "0181", "name": "MED INT MULTI ORG HC"}],
                "transcriptionist": None,
                "results": [
                    {
                        "code": "ECBU_CULT_BILAN",
                        "type": "CE",
                        "sub_code": None,
                        "value": [
                            {
                                "value": "POS_S_QUAN",
                                "label": "Culture positive",
                                "codification": "L",
                                "multiple_clarilab": [
                                    [
                                        "J2",
                                        "CPS",
                                        1,
                                        "10^5",
                                        "l+",
                                        "G_562",
                                        "#",
                                        "3M",
                                        "CEF+",
                                        "OUI",
                                        "#",
                                        "#",
                                        "AERTA",
                                        "#",
                                        "R_GERMAERA",
                                        "J1",
                                        "ANC",
                                        "2",
                                        "10^7",
                                        "#",
                                        "G_562",
                                        "#",
                                        "M4",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        4,
                                        "10*3",
                                        "#",
                                        "G_1280",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        5,
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                        "#",
                                    ]
                                ],
                                "json": {
                                    "germes": [
                                        {
                                            "Delai": "J2",
                                            "Gélose ?": "CPS",
                                            "rang": 1,
                                            "qty": "10^5",
                                            "Aspect": "l+",
                                            "id": "G_562",
                                            "score": [],
                                            "Morphotype": "3M",
                                            "Tests comp": "CEF+",
                                            "ATB": "OUI",
                                            "Date ATBg": [],
                                            "Cf dossier": [],
                                            "Souchothèque": "AERTA",
                                            "Ri/Autres informations": [],
                                            "Rendu du germe ?": "R_GERMAERA",
                                        },
                                        {
                                            "Delai": "J1",
                                            "Gélose ?": "ANC",
                                            "rang": "2",
                                            "qty": "10^7",
                                            "Aspect": [],
                                            "id": "G_562",
                                            "score": [],
                                            "Morphotype": "M4",
                                            "Tests comp": [],
                                            "ATB": [],
                                            "Date ATBg": [],
                                            "Cf dossier": [],
                                            "Souchothèque": [],
                                            "Ri/Autres informations": [],
                                            "Rendu du germe ?": [],
                                        },
                                        {
                                            "Delai": [],
                                            "Gélose ?": [],
                                            "rang": 4,
                                            "qty": "10*3",
                                            "Aspect": [],
                                            "id": "G_1280",
                                            "score": [],
                                            "Morphotype": [],
                                            "Tests comp": [],
                                            "ATB": [],
                                            "Date ATBg": [],
                                            "Cf dossier": [],
                                            "Souchothèque": [],
                                            "Ri/Autres informations": [],
                                            "Rendu du germe ?": [],
                                        },
                                        {
                                            "Delai": [],
                                            "Gélose ?": [],
                                            "rang": 5,
                                            "qty": [],
                                            "Aspect": [],
                                            "id": [],
                                            "score": [],
                                            "Morphotype": [],
                                            "Tests comp": [],
                                            "ATB": [],
                                            "Date ATBg": [],
                                            "Cf dossier": [],
                                            "Souchothèque": [],
                                            "Ri/Autres informations": [],
                                            "Rendu du germe ?": [],
                                        },
                                    ],
                                    "type_resultat": "identification_germes",
                                    "resultat": "POS_S_QUAN",
                                },
                                "schema": {
                                    "type": "object",
                                    "properties": {
                                        "germes": {
                                            "title": "germes",
                                            "type": "array",
                                            "propertyOrder": 0,
                                            "items": {
                                                "type": "object",
                                                "properties": {
                                                    "Delai": {
                                                        "type": "string",
                                                        "format": {
                                                            "mode_saisie": "combo",
                                                            "code": "Delai",
                                                            "libelle": "??? Delai",
                                                            "classtcode": ["DELAIS"],
                                                            "largeur": "1",
                                                            "textescodes": {
                                                                "J2": ("J2", "J2", "L"),
                                                                "J1": ("J1", "J1", "L"),
                                                            },
                                                        },
                                                        "propertyOrder": 0,
                                                    },
                                                    "Gélose ?": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "Gélose ?",
                                                            "libelle": "????? Gélose",
                                                            "classtcode": [
                                                                "MilieuxECBU"
                                                            ],
                                                            "mode_saisie": "combo",
                                                            "largeur": "1",
                                                            "textescodes": {
                                                                "CPS": (
                                                                    "CPS",
                                                                    "CPS",
                                                                    "L",
                                                                ),
                                                                "ANC": (
                                                                    "ANC",
                                                                    "ANC",
                                                                    "L",
                                                                ),
                                                            },
                                                        },
                                                        "propertyOrder": 1,
                                                    },
                                                    "rang": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "rang",
                                                            "libelle": "Rang",
                                                            "mode_saisie": "text",
                                                            "largeur": "1",
                                                        },
                                                        "propertyOrder": 2,
                                                    },
                                                    "qty": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "qty",
                                                            "libelle": "??????? Quantité",
                                                            "classtcode": ["QT_ECBU"],
                                                            "mode_saisie": "combo",
                                                            "largeur": "2",
                                                            "textescodes": {
                                                                "10^5": (
                                                                    "10^5",
                                                                    "10^5",
                                                                    "L",
                                                                ),
                                                                "10^7": (
                                                                    "10^7",
                                                                    "10^7",
                                                                    "L",
                                                                ),
                                                                "10*3": (
                                                                    "10*3",
                                                                    "10*3",
                                                                    "L",
                                                                ),
                                                            },
                                                        },
                                                        "propertyOrder": 3,
                                                    },
                                                    "Aspect": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "Aspect",
                                                            "libelle": "Aspect",
                                                            "mode_saisie": "text",
                                                            "largeur": "2",
                                                        },
                                                        "propertyOrder": 4,
                                                    },
                                                    "id": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "id",
                                                            "libelle": "Identification",
                                                            "mode_saisie": "popup",
                                                            "largeur": "2",
                                                            "classtcode": ["GERME"],
                                                            "textescodes": {
                                                                "G_562": (
                                                                    "G_562",
                                                                    "Escherichia coli",
                                                                    "L",
                                                                ),
                                                                "G_1280": (
                                                                    "G_1280",
                                                                    "Staphylococcus aureus",
                                                                    "L",
                                                                ),
                                                            },
                                                        },
                                                        "propertyOrder": 5,
                                                    },
                                                    "score": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "score",
                                                            "libelle": "score",
                                                            "mode_saisie": "text",
                                                            "largeur": "1",
                                                        },
                                                        "propertyOrder": 6,
                                                    },
                                                    "Morphotype": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "Morphotype",
                                                            "classtcode": ["MORPHOT"],
                                                            "mode_saisie": "popup",
                                                            "largeur": "1",
                                                            "libelle": "Morphotype",
                                                            "textescodes": {
                                                                "3M": (
                                                                    "3M",
                                                                    "3 morphotypes",
                                                                    "L",
                                                                ),
                                                                "M4": (
                                                                    "M4",
                                                                    "Morphotype 4",
                                                                    "L",
                                                                ),
                                                            },
                                                        },
                                                        "propertyOrder": 7,
                                                    },
                                                    "Tests comp": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "Tests comp",
                                                            "libelle": "Tests comp",
                                                            "classtcode": ["TEST_COM"],
                                                            "mode_saisie": "popup",
                                                            "largeur": "1",
                                                            "textescodes": {
                                                                "CEF+": (
                                                                    "CEF+",
                                                                    "producteur de béta-lactamase",
                                                                    "L",
                                                                )
                                                            },
                                                        },
                                                        "propertyOrder": 8,
                                                    },
                                                    "ATB": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "ATB",
                                                            "libelle": "ATBG?",
                                                            "classtcode": ["ATBG"],
                                                            "mode_saisie": "popup",
                                                            "largeur": "1",
                                                            "textescodes": {
                                                                "OUI": (
                                                                    "OUI",
                                                                    "Oui",
                                                                    "L",
                                                                )
                                                            },
                                                        },
                                                        "propertyOrder": 9,
                                                    },
                                                    "Date ATBg": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "Date ATBg",
                                                            "libelle": "Date ATBg",
                                                            "mode_saisie": "text",
                                                            "largeur": "1",
                                                        },
                                                        "propertyOrder": 10,
                                                    },
                                                    "Cf dossier": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "Cf dossier",
                                                            "libelle": "Cf dossier",
                                                            "mode_saisie": "text",
                                                            "largeur": "1",
                                                        },
                                                        "propertyOrder": 11,
                                                    },
                                                    "Souchothèque": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "Souchothèque",
                                                            "libelle": "Souchothèque",
                                                            "classtcode": ["SOUCHE"],
                                                            "mode_saisie": "popup",
                                                            "largeur": "1",
                                                            "textescodes": {
                                                                "AERTA": (
                                                                    "AERTA",
                                                                    "Aérobie (T ambiante)",
                                                                    "L",
                                                                )
                                                            },
                                                        },
                                                        "propertyOrder": 12,
                                                    },
                                                    "Ri/Autres informations": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "Ri/Autres informations",
                                                            "libelle": "Ri/Autres informations",
                                                            "mode_saisie": "text",
                                                            "largeur": "1",
                                                        },
                                                        "propertyOrder": 13,
                                                    },
                                                    "Rendu du germe ?": {
                                                        "type": "string",
                                                        "format": {
                                                            "code": "Rendu du germe ?",
                                                            "libelle": "Rendu du germe ?",
                                                            "classtcode": ["REND_GER"],
                                                            "mode_saisie": "popup",
                                                            "largeur": "1",
                                                            "textescodes": {
                                                                "R_GERMAERA": (
                                                                    "R_GERMAERA",
                                                                    "A: Germe rendu",
                                                                    "L",
                                                                )
                                                            },
                                                        },
                                                        "propertyOrder": 14,
                                                    },
                                                },
                                            },
                                        }
                                    },
                                },
                            }
                        ],
                        "flags": [],
                        "date": datetime.datetime(2024, 3, 13, 10, 48, 14, 837821),
                        "operator": None,
                        "status": "P",
                        "validator": "01583979",
                        "unit": "",
                        "nom_antibiogramme": None,
                        "instrument": "Manuel",
                        "lots": [],
                    }
                ],
            }
        ],
        "context": "result",
        "sender_id": "BACEXPRESS",
        "sender_name": "BAC EXPRESS TEST",
        "receiver_id": "SIL",
        "receiver_name": "TEST SIL HL7",
    }
    result_worklist = Worklist(**wkjson)
    message = self.encode(result_worklist, context={"control_id": "1521651964637"})
    expect = [
        "MSH|^~\\&|MCA||||20130715141912||OUL^R22^OUL_R22|1521651964637||2.5.1|||AL|NE||UNICODE UTF-8",
        "PID|1|581312|581312||CIRCUIT^TRACABILITE^^^Mr|CIRCUIT|19820101|M",
        "PV1|1||0181|||||01981949|||||||||||7099166107",
        "SPM|1|124112003102||BACTERIO|||||||P||||||20240312134600|20240312134640",
        "OBR|1|1241120031|124112003102|ECBU_CULT_BILAN||||||||||||01981949^Riccio Nicolas|||||||||||^^^20240312134600^^R",
        "OBX|1|CE|ECBU_CULT_BILAN||POS_S_QUAN^Culture positive^L||||||P|||20240313104814||01583979||Manuel",
        "OBX|2|CE|ECBU_CULT_BILAN^^COMPLEXE^1||1^G_562&Escherichia coli&id^10\\R\\5&10\\R\\5&qty||||||P|||20240313104814|^^ECBU_CULT_BILAN|01583979||Manuel",
        "OBX|3|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Delai|J2|||||||||20240313104814",
        "OBX|4|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Gélose ?|CPS|||||||||20240313104814",
        "OBX|5|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Aspect|l+|||||||||20240313104814",
        "OBX|6|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Morphotype|3M|||||||||20240313104814",
        "OBX|7|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Tests comp|CEF+|||||||||20240313104814",
        "OBX|8|CE|ECBU_CULT_BILAN^^COMPLEXE^1|ATB|OUI|||||||||20240313104814",
        "OBX|9|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Souchothèque|AERTA|||||||||20240313104814",
        "OBX|10|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Rendu du germe ?|R_GERMAERA|||||||||20240313104814",
        "OBX|11|CE|ECBU_CULT_BILAN^^COMPLEXE^2||2^G_562&Escherichia coli&id^10\\R\\7&10\\R\\7&qty||||||P|||20240313104814|^^ECBU_CULT_BILAN|01583979||Manuel",
        "OBX|12|CE|ECBU_CULT_BILAN^^COMPLEXE^2|Delai|J1|||||||||20240313104814",
        "OBX|13|CE|ECBU_CULT_BILAN^^COMPLEXE^2|Gélose ?|ANC|||||||||20240313104814",
        "OBX|14|CE|ECBU_CULT_BILAN^^COMPLEXE^2|Morphotype|M4|||||||||20240313104814",
        "OBX|15|CE|ECBU_CULT_BILAN^^COMPLEXE^4||3^G_1280&Staphylococcus aureus&id^10*3&10*3&qty||||||P|||20240313104814|^^ECBU_CULT_BILAN|01583979||Manuel",
        "OBX|16|CE|ECBU_CULT_BILAN^^COMPLEXE^5||4^[]&&id^[]&&qty||||||P|||20240313104814|^^ECBU_CULT_BILAN|01583979||Manuel",
    ]
    assert message == "\n".join(expect)
    self.configure(option_envoie_germe="Rendu du germe ?:R_GERMAERA")
    message = self.encode(result_worklist, context={"control_id": "1521651964637"})
    expect = [
        "MSH|^~\\&|MCA||||20130715141912||OUL^R22^OUL_R22|1521651964637||2.5.1|||AL|NE||UNICODE UTF-8",
        "PID|1|581312|581312||CIRCUIT^TRACABILITE^^^Mr|CIRCUIT|19820101|M",
        "PV1|1||0181|||||01981949|||||||||||7099166107",
        "SPM|1|124112003102||BACTERIO|||||||P||||||20240312134600|20240312134640",
        "OBR|1|1241120031|124112003102|ECBU_CULT_BILAN||||||||||||01981949^Riccio Nicolas|||||||||||^^^20240312134600^^R",
        "OBX|1|CE|ECBU_CULT_BILAN||POS_S_QUAN^Culture positive^L||||||P|||20240313104814||01583979||Manuel",
        "OBX|2|CE|ECBU_CULT_BILAN^^COMPLEXE^1||1^G_562&Escherichia coli&id^10\\R\\5&10\\R\\5&qty||||||P|||20240313104814|^^ECBU_CULT_BILAN|01583979||Manuel",
        "OBX|3|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Delai|J2|||||||||20240313104814",
        "OBX|4|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Gélose ?|CPS|||||||||20240313104814",
        "OBX|5|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Aspect|l+|||||||||20240313104814",
        "OBX|6|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Morphotype|3M|||||||||20240313104814",
        "OBX|7|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Tests comp|CEF+|||||||||20240313104814",
        "OBX|8|CE|ECBU_CULT_BILAN^^COMPLEXE^1|ATB|OUI|||||||||20240313104814",
        "OBX|9|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Souchothèque|AERTA|||||||||20240313104814",
        "OBX|10|CE|ECBU_CULT_BILAN^^COMPLEXE^1|Rendu du germe ?|R_GERMAERA|||||||||20240313104814",
    ]
    assert message == "\n".join(expect)
