# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "kone"


def test_order(self):
    result = self.order()
    expected = """H|\\^&|||LIS|||||||P||20130715141912
        P|1|036666666|||NYME^ANO||20110513|F
        O|1|123456||^^^A|A||20130513114242||||N||||Serum||||||||||Q\\O
        O|2|123456||^^^B|A||20130513114242||||A||||Serum||||||||||Q\\O
        O|3|123456||^^^C|A||20130513114242||||C||||Serum||||||||||Q\\O
        L|1|N"""
    assert result == expected


def test_result(self):
    result = self.decode(
        """H|\\^&|||^1^6.5.4|||||||P
        P|1|04000087533|||TEST ANONYME||19820413
        O|1|199011979999^0.0^3^3||^^^ALL^|R||20130716112341||||X||||1|||||||||1|F
        R|1|^^^ALDO^0.0|12.0|U/l|^^|>||F||OPE||20130718103929|1
        C|1|I|11 Test limit high|I
        R|2|^^^ECA^0.0|15|UI/l|^^|>||F\\R||OPE||20130718104218|1
        R|3|^^^ECA^0.0|21|UI/l|^^|N||F||OPE||20130718104649|1
        L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "199011979999",
                "results": [
                    {
                        "flags": [">", "11"],
                        "date": datetime.datetime(2013, 7, 18, 10, 39, 29),
                        "value": "12.0",
                        "code": "ALDO",
                        "operator": "OPE",
                    },
                    {
                        "flags": ["N"],
                        "date": datetime.datetime(2013, 7, 18, 10, 46, 49),
                        "value": "21",
                        "code": "ECA",
                        "operator": "OPE",
                    },
                ],
            }
        ],
    }
    assert result == expected


def test_qc_result(self):
    result = self.decode(
        """H|\\^&|||^1^6.5.4|||||||Q
        P|1
        O|1|ALS CQ 2||^^^ALDO^0.0|S||||||Q||||1|||||||||1|F
        R|1|^^^ALDO^0.0|7.7|U/l|^^|N||F||||20130711113900|1
        L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "ALS CQ 2",
                "control_lot": "ALS CQ 2",
                "results": [
                    {
                        "flags": ["N"],
                        "date": datetime.datetime(2013, 7, 11, 11, 39),
                        "value": "7.7",
                        "code": "ALDO",
                        "operator": "",
                    }
                ],
            }
        ],
    }
    assert result == expected
