# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

from driverng.tests import BaseTest


class TestProtocol(BaseTest):
    PROTOCOL_CLASS = "cobas_pure"

    QBP_Q11_MESSAGE = """MSH|^~\\&|cpure||host||20160724080600+0200||QBP^Q11^QBP_Q11|1234|P|2.5.1|||NE|AL|UNICODE UTF-8|||LAB-27R^ROCHE
    QPD|INIBAR^^99ROC|query1234|10001|50001|1|||||SERPLAS^^99ROC|SC^^99ROC|S
    RCP|I|1|S^^HL70394
    """

    OUL_R22_MESSAGE = """MSH|^~\\&|cpure||host||20180222150842+0100||OUL^R22^OUL_R22|97|P|2.5.1|||NE|AL||UNICODE UTF-8|||LAB-29^IHE
    PID|||||^^^^^^U|||U
    SPM|1|022&BARCODE||SERPLAS^^99ROC|||||||P^^HL70369|||~~~~||||||||||PSCO^^99ROC|||SC^^99ROC
    SAC|||022^BARCODE|||||||50120|2||||||||||||||||||^1^:^1
    OBR|1|""||20490^^99ROC|||||||
    ORC|SC||||CM
    TQ1|||||||||R^^HL70485
    OBX|1|NM|20490^20490^99ROC^^^IHELAW|1|32.2|mg/L^^99ROC||N^^HL70078|||F|||||Admin~REALTIME||c303^ROCHE~3333^ROCHE~1^ROCHE|20180222150842||||||||||RSLT
    OBX|2|CE|20490^20490^99ROC^^^IHELAW|1|^^99ROC|||N^^HL70078|||F|||||Admin~REALTIME||c303^ROCHE~3333^ROCHE~1^ROCHE|20180222150842||||||||||RSLT
    TCD|20490^^99ROC|^1^:^1
    INV|2049001|OK^^HL70383~CURRENT^^99ROC|R1|514|1|8||||||20181030||||256616
    INV|2049001|OK^^HL70383~CURRENT^^99ROC|R3|514|1|8||||||20181030||||256616
    """

    EQU_MASSAGE = """MSH|^~\\&|cpure||host||20171012181115+0900||ESU^U01^ESU_U01|3|P|2.5.1|||NE|AL||UNICODE UTF-8|||ROC-02^ROCHE
    EQU|^ROCHE~P00001^ROCHE~0^ROCHE|20171012181115|OP^NORMAL_OPERATION^99LECIS^29^Start^99HITACHI<CR>"""

    def test_ack_query(self):
        message = self.P.get_ack_message(
            self.QBP_Q11_MESSAGE.encode(),
            control_id=b"1657528152616",
            date=datetime.datetime(2022, 7, 11, 10, 29, 12),
        )
        expected = b"""MSH|^~\\&|host||cpure||20220711102912||RSP^K11^RSP_K11|1657528152616|P|2.5.1|||||UNICODE UTF-8|||LAB-27R^ROCHE\rMSA|AA|1234\rQAK|query1234|OK|INIBAR^^99ROC\rQPD|INIBAR^^99ROC|query1234|10001|50001|1|||||SERPLAS^^99ROC|SC^^99ROC|S"""
        assert message == expected

    def test_ack_result(self):
        message = self.P.get_ack_message(
            self.OUL_R22_MESSAGE.encode(),
            control_id=b"1657542546717",
            date=datetime.datetime(2022, 7, 11, 14, 29, 6),
        )
        expected = b"""MSH|^~\\&|host||cpure||20220711142906||ACK^R22^ACK|1657542546717|P|2.5.1|||||UNICODE UTF-8|||LAB-29^IHE\rMSA|AA|97"""
        assert message == expected

    def test_ack_equ(self):
        message = self.P.get_ack_message(
            self.EQU_MASSAGE.encode(),
            control_id=b"1657528152616",
            date=datetime.datetime(2022, 7, 11, 10, 29, 12),
        )
        expected = b"""MSH|^~\\&|host||cpure||20220711102912||ACK^U01^ACK|1657528152616|P|2.5.1|||||UNICODE UTF-8|||ROC-02^ROCHE\rMSA|AA|3"""
        assert message == expected
