# -*- coding: utf8 -*-
from __future__ import unicode_literals

parser_class = "pvs"


def test_encode_order(self):
    _order_message = "TYP:RQ|SID:123456|SYS:|NAM:NYME_ANO|MAT:Serum|TST:Serum,A,B|"
    message = self.order()
    assert message == _order_message


def test_void_order_pvs_version_routage_archive(self):
    self.configure(pvs_version_routage_zone=True)
    message = self.order(
        worklist=self.void_worklist,
        context={"query": self.parse("TYP:LA|SID:123456|MAT:09 BD 100*13 red|")},
    )
    expected = "TYP:RQ|SID:123456|SYS:|NAM:|MAT:|TST:ERREUR|"
    assert message == expected


def test_encode_order_pvs_version_routage_zone(self):
    self.configure(pvs_version_routage_zone=True)
    _order_message = "TYP:RW|SID:123456|SYS:|NAM:NYME_ANO|MAT:Serum|TST:ZONE1,STAT|"
    message = self.order()
    assert message == _order_message


def test_encode_order_pvs_routage_zone_mode_rs(self):
    self.configure(pvs_version_routage_zone=True, pvs_mode_rs=True)
    _order_message = "TYP:RS|SID:123456|SYS:|NAM:NYME_ANO|MAT:Serum|TST:ZONE1,STAT|"
    message = self.order()
    assert message == _order_message


def test_decode_query(self):
    worklist = self.decode("TYP:LA|SID:8124039595|")
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "8124039595", "sample_color": ""}],
    }
    assert worklist == expected


def test_decode_query_pvs_version_routage_zone(self):
    self.configure(pvs_version_routage_zone=True)
    worklist = self.decode("TYP:LA|SID:42837383|MAT:09 BD 100*13 red|")
    expected = {
        "context": "query",
        "samples": [
            {"type": "patient", "sample_id": "42837383", "sample_color": "ff0000"}
        ],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode("TYP:WP|SID:123456|POS:011|")
    expected = {
        "context": "result",
        "samples": [{"rack": "011", "sample_id": "123456", "type": "patient"}],
    }
    assert worklist == expected


def test_decode_result_pvs_version_routage_zone(self):
    self.configure(pvs_version_routage_zone=True)
    worklist = self.decode("TYP:WP|SID:123456|TRG:HIT_KC|POS:011|")
    expected = {
        "context": "result",
        "samples": [{"rack": "HIT_KC-011", "sample_id": "123456", "type": "patient"}],
    }
    assert worklist == expected
