# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "sorting_drive"


def test_encode_order(self):
    expected = """;123456;123456;1;1;F;;13/05/2011;NYME-ANO;;;;;;A|
    ;123456;123456;1;2;F;;13/05/2011;NYME-ANO;;;;;;C|
    """
    message = self.order()
    assert message == expected


def test_decode_result_other_format_date(self):
    self.configure(sorting_format_date="3")
    worklist = self.decode(
        """
    192.168.0.2;45483;081505002510;081505002510;0;1;10;N/A;150;4;3;5/15/2023 2:41:08 PM;2290;FOLA~VB12;
    192.168.0.10;Labo;051505506008;051505506008;0;2;08;LU-JE27;999;2;4;5/15/2023 2:41:09 PM;0;ACVP;
    192.168.0.2;Labo;121505000310;121505000310;0;1;10;N/A;360;3;4;5/15/2023 2:41:11 PM;2176;BW;
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "150-4-3",
                "results": [
                    {
                        "code": "TRACKING",
                        "comments": ["Volume: 2290"],
                        "date": datetime.datetime(2023, 5, 15, 14, 41, 8),
                        "value": "150",
                        "preanalytique": True,
                    }
                ],
                "sample_id": "081505002510",
                "type": "patient",
            },
            {
                "rack": "LU-JE27-2-4",
                "results": [
                    {
                        "code": "TRACKING",
                        "comments": ["LU-JE27", "Volume: 0"],
                        "date": datetime.datetime(2023, 5, 15, 14, 41, 9),
                        "preanalytique": True,
                        "value": "999",
                    }
                ],
                "sample_id": "051505506008",
                "type": "patient",
            },
            {
                "rack": "360-3-4",
                "results": [
                    {
                        "code": "TRACKING",
                        "comments": ["Volume: 2176"],
                        "date": datetime.datetime(2023, 5, 15, 14, 41, 11),
                        "preanalytique": True,
                        "value": "360",
                    }
                ],
                "sample_id": "121505000310",
                "type": "patient",
            },
        ],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    192.168.1.1;Lab1;6322486;1234560;1;1;2;N/A;320;07;01;15.12.09 4:38:54 PM;450;FT4~T3~HBAC;
    192.168.1.1;Lab2;6322487;1112223;2;4;2;99064919;112;07;20151203_123854;;;;
    10.1.59.20;N/A;370311006007;370311006007;0;2;1;VERT-05;980;7;3;21.10.06 7:53:06 PM;0;ACVP;
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "320-07-01",
                "results": [
                    {
                        "code": "TRACKING",
                        "comments": ["Volume: 450"],
                        "date": datetime.datetime(2015, 12, 9, 16, 38, 54),
                        "value": "320",
                        "preanalytique": True,
                    }
                ],
                "sample_id": "6322486",
                "type": "patient",
            },
            {
                "rack": "4",
                "sample_id": "6322487",
                "results": [
                    {
                        "code": "TRACKINGT",
                        "value": "4",
                        "date": datetime.datetime(2015, 12, 3, 12, 38, 54),
                        "comments": ["Volume: 2"],
                        "flags": ["Cap color: 2"],
                    }
                ],
                "type": "patient",
            },
            {
                "rack": "VERT-05-7-3",
                "results": [
                    {
                        "code": "TRACKING",
                        "comments": ["VERT-05", "Volume: 0"],
                        "date": datetime.datetime(2021, 10, 6, 19, 53, 6),
                        "preanalytique": True,
                        "value": "980",
                    }
                ],
                "sample_id": "370311006007",
                "type": "patient",
            },
        ],
    }
    assert worklist == expected


def test_decode_color_result(self):
    self.configure(transcodage_bouchon="2:rouge, 3:bleu")
    worklist = self.decode(
        """
    192.168.1.1;Lab2;6322487;1112223;2;4;2;99064919;112;07;20151203_123854;;;;
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "6322487",
                "rack": "4",
                "type": "patient",
                "results": [
                    {
                        "code": "TRACKINGT",
                        "value": "4",
                        "date": datetime.datetime(2015, 12, 3, 12, 38, 54),
                        "comments": ["Volume: 2"],
                        "flags": ["Cap color: rouge"],
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_error(self):
    self.configure(sorting_rackid_error=True)
    worklist = self.decode(
        """
    127.0.0.1;;19200003301;19200003301;0;1;12;N/A;101;0;0;19.05.06 05:52:22 PM;0;CLU~KU~NAU;
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "101-0-0",
                "results": [{"code": "TRANSFERT_ERREUR_PLACEMENT", "value": "101"}],
                "sample_id": "19200003301",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_tube(self):
    worklist = self.decode(
        """
    192.168.1.2;N/A;CV4093110042;4;-3;98;1296;0;0;0;20240402_130246;;;;
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "CV4093110042",
                "rack": "98",
                "type": "patient",
                "results": [
                    {
                        "code": "TRACKINGT",
                        "value": "98",
                        "date": datetime.datetime(2024, 4, 2, 13, 2, 46),
                        "comments": ["Volume: 1296"],
                        "flags": ["Cap color: -3"],
                    }
                ],
            }
        ],
    }
    assert worklist == expected
